import requests
import datetime

from awattar.marketitem import MarketItem

class AwattarClient(object):
    def __init__(self,
                 country='AT'
                 ):
        """Construct a new AwattarClient object."""

        self._country = country 

    def request(self,
                start_time = None,
                end_time = None
                ):
        """
        Get Market data between start time and end time

        Parameters
        ----------
        start_time : datetime
            Start time
        end_time : datetime
            End time            

        Returns
        -------
        MarketItem
            Returns list of MarketItem

        """                   

        #set params
        params = ''
        if start_time != None:
            params = '?start=' + str(int(start_time.timestamp())) + '000'

            if end_time != None:
                #set end timestamp
                params = params + '&end=' + str(int(end_time.timestamp())) + '000'

        #build url
        if self._country == 'AT':
            url = 'https://api.awattar.com/v1/marketdata' + params
        elif self._country == 'DE':
            url = 'https://api.awattar.de/v1/marketdata' + params

        #send request
        req = requests.get(url)

        if req.status_code != requests.codes.ok: return None

        jsondata = req.json()
        data = [MarketItem(**k) for k in jsondata["data"]]

        return data



import datetime
from dateutil import tz

class MarketItem(object):
    def __init__(self,
                 start_timestamp,
                 end_timestamp,
                 marketprice,
                 unit
                 ):
        """Construct a new aWATTarClient item object."""

        self._start_timestamp = start_timestamp
        self._end_timestamp = end_timestamp
        self._marketprice = marketprice
        self._unit = unit

    @property
    def start_datetime(self):

        #get datetime in utc
        value = datetime.datetime.utcfromtimestamp(self._start_timestamp / 1000).replace(tzinfo=datetime.timezone.utc) 

        #return in local timezone
        return value.astimezone(tz.tzlocal()) 
    
    @property
    def end_datetime(self):
        #get datetime in utc
        value = datetime.datetime.utcfromtimestamp(self._end_timestamp / 1000).replace(tzinfo=datetime.timezone.utc) 

        #return in local timezone
        return value.astimezone(tz.tzlocal()) 

    @property
    def marketprice(self):
        return self._marketprice

    @property
    def unit(self):
        return self._unit;        